@@ -41,7 +41,7 @@ dopri853 <- function(y, times, func, parms, rtol=1e-6, atol=1e-6,
   flist     <- list(fmat=0,tmat=0,imat=0,ModelForc=NULL)
   ModelInit <- NULL
 
-  if (is.character(func)  | class(func) == "CFunc") {   # function specified in a DLL
+  if (is.character(func)  | inherits(func, "CFunc")) {   # function specified in a DLL
     DLL <- checkDLL(func,NULL,dllname,
                     initfunc,verbose,nout, outnames)
 
